macro_rules! cooldown {
($period:expr) => { ... };
($period:expr, $body:expr) => { ... };
}Expand description
A simple macro to check if a cooldown period has passed since the last time.
macro_rules! cooldown {
($period:expr) => { ... };
($period:expr, $body:expr) => { ... };
}A simple macro to check if a cooldown period has passed since the last time.